Semigroup<T> mixin
A semigroup is any set A with an associative operation (combine).
(xy)z = x(yz) = xyz for all x, y, z in A
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
combine(
T x, T y) → T - Associative operation which combines two values.
-
combineN(
T a, int n) → T -
Return
acombined with itselfntimes. -
intercalate(
T middle) → Semigroup< T> -
Return a
Semigroupwhich insertsmiddlebetween each pair of elements. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverse(
) → Semigroup< T> -
Return a
Semigroupthat reverses the order. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited